==> eiffelstudio-18.07.10.1981.tar: F_code/C11/ev535.c <==
/*
 * Code for class EV_FILE_DIALOG_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev535.h"
#include <stdio.h>
#include <ev_gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F14_930
static EIF_POINTER inline_F14_930 (EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
{
	return (EIF_POINTER) (gtk_file_chooser_dialog_new ((gchar*) arg1, (GtkWindow*) arg2, (GtkFileChooserAction) arg3, NULL, NULL))
	;
}
#define INLINE_F14_930
#endif
#ifndef INLINE_F14_922
static EIF_POINTER inline_F14_922 (EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
{
	return (EIF_POINTER) (gtk_dialog_add_button ((GtkDialog*) arg1, (gchar*) arg2, (gint) arg3))
	;
}
#define INLINE_F14_922
#endif
#ifndef INLINE_F14_936
static void inline_F14_936 (EIF_POINTER arg1, EIF_BOOLEAN arg2)
{
	gtk_file_chooser_set_local_only ((GtkFileChooser*) arg1, (gboolean) arg2)
	;
}
#define INLINE_F14_936
#endif
#ifndef INLINE_F14_923
static void inline_F14_923 (EIF_POINTER arg1, EIF_INTEGER_32 arg2)
{
	gtk_dialog_set_default_response ((GtkDialog*) arg1, (gint) arg2)
	;
}
#define INLINE_F14_923
#endif
#ifndef INLINE_F14_932
static EIF_POINTER inline_F14_932 (EIF_POINTER arg1)
{
	return (EIF_POINTER) (gtk_file_chooser_get_filename ((GtkFileChooser*) arg1))
	;
}
#define INLINE_F14_932
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_FILE_DIALOG_IMP}.make */
void F1171_10671 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_POINTER loc2 = (EIF_POINTER) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc3);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Current);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(817, 0x00).id, 817, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("Select file",11,1098209125);
	F818_5654(RTCW(tr1), tr2);
	loc3 = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(RTCW(loc3)+ _PTROFF_0_1_0_1_0_0_);
	tp2 = (EIF_POINTER) NULL;
	ti4_1 = (RTNR(NULL), ((EIF_INTEGER_32) 0));
	tp1 = inline_F14_930(tp1, tp2, ti4_1);
	F1126_10248(Current, tp1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,698,0xFF01,0xFFF9,2,880,0xFF01,959,0xFF01,959,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F699_5016(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	F1127_10265(Current);
	F1100_9575(Current, (EIF_BOOLEAN) 0);
	tr1 = RTMS32_EX_H("*\000\000\000.\000\000\000*\000\000\000",3,2764330);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = (EIF_POINTER) GTK_STOCK_CANCEL;
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_CANCEL;
	loc2 = inline_F14_922(tp1, tp2, ti4_1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = (EIF_POINTER) GTK_STOCK_OK;
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_ACCEPT;
	loc1 = inline_F14_922(tp1, tp2, ti4_1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	inline_F14_936(tp1, (EIF_BOOLEAN) 1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_ACCEPT;
	inline_F14_923(tp1, ti4_1);
	tr1 = RTMS_EX_H("clicked",7,169941860);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,880,0xFF01,831,952,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr2 = RTLNTS(typres0.id, 3, 0);
	}
	tr3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(10262,F1126_10262,(Current))) + _REFACS_42_);
	((EIF_TYPED_VALUE *)tr2+1)->it_r = tr3;
	RTAR(tr2,tr3);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	((EIF_TYPED_VALUE *)tr2+2)->it_p = tp1;
	
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,954,0xFF01,0xFFF9,0,880,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNRF(typres0.id, (EIF_POINTER) __A284_336, (EIF_POINTER) _A284_336, (EIF_POINTER)(F829_6311),tr2, 1, 0);
	}
	F1126_10253(Current, loc1, tr1, tr3, NULL);
	tr1 = RTMS_EX_H("clicked",7,169941860);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,880,0xFF01,831,952,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr2 = RTLNTS(typres0.id, 3, 0);
	}
	tr3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(10262,F1126_10262,(Current))) + _REFACS_42_);
	((EIF_TYPED_VALUE *)tr2+1)->it_r = tr3;
	RTAR(tr2,tr3);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	((EIF_TYPED_VALUE *)tr2+2)->it_p = tp1;
	
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,954,0xFF01,0xFFF9,0,880,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNRF(typres0.id, (EIF_POINTER) __A284_337, (EIF_POINTER) _A284_337, (EIF_POINTER)(F829_6312),tr2, 1, 0);
	}
	F1126_10253(Current, loc2, tr1, tr3, NULL);
	F1169_10656(Current);
	tr1 = F694_4927(RTCV(RTOSCF(10262,F1126_10262,(Current))));
	F1171_10678(Current, tr1);
	F1100_9575(Current, (EIF_BOOLEAN) 1);
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.filter */
EIF_REFERENCE F1171_10673 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_9_);
}


/* {EV_FILE_DIALOG_IMP}.start_path */
EIF_REFERENCE F1171_10675 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_8_);
}


/* {EV_FILE_DIALOG_IMP}.set_start_path */
void F1171_10678 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNS(eif_new_type(817, 0x01).id, 817, _OBJSIZ_0_1_0_1_0_1_0_0_);
	F818_5649(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
	gtk_file_chooser_set_current_folder((GtkFileChooser*) tp1, (gchar*) tp2);
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.on_ok */
void F1171_10679 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_POINTER loc3 = (EIF_POINTER) 0;
	EIF_POINTER tp1;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	loc3 = inline_F14_932(tp1);
	if ((EIF_BOOLEAN)(loc3 != (EIF_POINTER) NULL)) {
		tr1 = RTLNS(eif_new_type(833, 0x01).id, 833, _OBJSIZ_2_1_0_0_0_0_0_0_);
		F834_6404(RTCW(tr1), loc3);
		loc1 = (EIF_REFERENCE) tr1;
		tr1 = RTLNS(eif_new_type(823, 0x01).id, 823, _OBJSIZ_4_6_2_4_1_1_2_1_);
		F823_5922(RTCW(tr1), loc1);
		loc2 = (EIF_REFERENCE) tr1;
		tb1 = '\01';
		tb2 = F823_5952(RTCW(loc2));
		if (!(EIF_BOOLEAN) !tb2) {
			tb2 = F823_5961(RTCW(loc2));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F1169_10661(Current);
		}
		g_free((gpointer) loc3);
	}
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.interface */
static EIF_REFERENCE F1171_10685_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F1171_10685 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if (!r) {
		if (RTAT(eif_final_id(Y7673,Y7673_gen_type,Dftype(Current),1099))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F1171_10685_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit535 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C11/ev535.c <==
/*
 * Code for class EV_FILE_DIALOG_IMP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ev535.h"
#include <ev_gtk.h>
#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifndef INLINE_F13_364
static EIF_POINTER inline_F13_364 (EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
{
	return (EIF_POINTER) (gtk_file_chooser_dialog_new ((gchar*) arg1, (GtkWindow*) arg2, (GtkFileChooserAction) arg3, NULL, NULL))
	;
}
#define INLINE_F13_364
#endif
#ifndef INLINE_F13_356
static EIF_POINTER inline_F13_356 (EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
{
	return (EIF_POINTER) (gtk_dialog_add_button ((GtkDialog*) arg1, (gchar*) arg2, (gint) arg3))
	;
}
#define INLINE_F13_356
#endif
#ifndef INLINE_F13_370
static void inline_F13_370 (EIF_POINTER arg1, EIF_BOOLEAN arg2)
{
	gtk_file_chooser_set_local_only ((GtkFileChooser*) arg1, (gboolean) arg2)
	;
}
#define INLINE_F13_370
#endif
#ifndef INLINE_F13_357
static void inline_F13_357 (EIF_POINTER arg1, EIF_INTEGER_32 arg2)
{
	gtk_dialog_set_default_response ((GtkDialog*) arg1, (gint) arg2)
	;
}
#define INLINE_F13_357
#endif
#ifndef INLINE_F13_366
static EIF_POINTER inline_F13_366 (EIF_POINTER arg1)
{
	return (EIF_POINTER) (gtk_file_chooser_get_filename ((GtkFileChooser*) arg1))
	;
}
#define INLINE_F13_366
#endif

#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EV_FILE_DIALOG_IMP}.make */
void F1174_10727 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER loc1 = (EIF_POINTER) 0;
	EIF_POINTER loc2 = (EIF_POINTER) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc3);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Current);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(820, 0x00).id, 820, _OBJSIZ_0_1_0_1_0_1_0_0_);
	tr2 = RTMS_EX_H("Select file",11,1098209125);
	F821_5705(RTCW(tr1), tr2);
	loc3 = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(RTCW(loc3)+ _PTROFF_0_1_0_1_0_0_);
	tp2 = (EIF_POINTER) NULL;
	ti4_1 = (RTNR(NULL), ((EIF_INTEGER_32) 0));
	tp1 = inline_F13_364(tp1, tp2, ti4_1);
	F1130_10311(Current, tp1);
	{
		static EIF_TYPE_INDEX typarr0[] = {581,0xFFF9,2,884,963,963,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F582_4871(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
	F1131_10328(Current);
	F1104_9638(Current, (EIF_BOOLEAN) 0);
	tr1 = RTMS32_EX_H("*\000\000\000.\000\000\000*\000\000\000",3,2764330);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_9_) = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = (EIF_POINTER) GTK_STOCK_CANCEL;
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_CANCEL;
	loc2 = inline_F13_356(tp1, tp2, ti4_1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = (EIF_POINTER) GTK_STOCK_OK;
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_ACCEPT;
	loc1 = inline_F13_356(tp1, tp2, ti4_1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	inline_F13_370(tp1, (EIF_BOOLEAN) 1);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	ti4_1 = (EIF_INTEGER_32) GTK_RESPONSE_ACCEPT;
	inline_F13_357(tp1, ti4_1);
	tr1 = RTMS_EX_H("clicked",7,169941860);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,884,835,956,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr2 = RTLNTS(typres0.id, 3, 0);
	}
	tr3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(10325,F1130_10325,(Current))) + _REFACS_42_);
	((EIF_TYPED_VALUE *)tr2+1)->it_r = tr3;
	RTAR(tr2,tr3);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	((EIF_TYPED_VALUE *)tr2+2)->it_p = tp1;
	
	{
		static EIF_TYPE_INDEX typarr0[] = {958,0xFFF9,0,884,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNRF(typres0.id, (EIF_POINTER) __A285_336, (EIF_POINTER) _A285_336, (EIF_POINTER)(F833_6372),tr2, 1, 0);
	}
	F1130_10316(Current, loc1, tr1, tr3, NULL);
	tr1 = RTMS_EX_H("clicked",7,169941860);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,884,835,956,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr2 = RTLNTS(typres0.id, 3, 0);
	}
	tr3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(10325,F1130_10325,(Current))) + _REFACS_42_);
	((EIF_TYPED_VALUE *)tr2+1)->it_r = tr3;
	RTAR(tr2,tr3);
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	((EIF_TYPED_VALUE *)tr2+2)->it_p = tp1;
	
	{
		static EIF_TYPE_INDEX typarr0[] = {958,0xFFF9,0,884,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNRF(typres0.id, (EIF_POINTER) __A285_337, (EIF_POINTER) _A285_337, (EIF_POINTER)(F833_6373),tr2, 1, 0);
	}
	F1130_10316(Current, loc2, tr1, tr3, NULL);
	F1173_10719(Current);
	tr1 = F577_4781(RTCV(RTOSCF(10325,F1130_10325,(Current))));
	F1174_10734(Current, tr1);
	F1104_9638(Current, (EIF_BOOLEAN) 1);
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.filter */
EIF_REFERENCE F1174_10729 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_9_);
}


/* {EV_FILE_DIALOG_IMP}.start_path */
EIF_REFERENCE F1174_10731 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_8_);
}


/* {EV_FILE_DIALOG_IMP}.set_start_path */
void F1174_10734 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	EIF_POINTER tp2;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_8_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNS(eif_new_type(820, 0x00).id, 820, _OBJSIZ_0_1_0_1_0_1_0_0_);
	F821_5700(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	tp2 = *(EIF_POINTER *)(RTCW(loc1)+ _PTROFF_0_1_0_1_0_0_);
	gtk_file_chooser_set_current_folder((GtkFileChooser*) tp1, (gchar*) tp2);
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.on_ok */
void F1174_10735 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_POINTER loc3 = (EIF_POINTER) 0;
	EIF_POINTER tp1;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_10_4_0_1_0_0_);
	loc3 = inline_F13_366(tp1);
	if ((EIF_BOOLEAN)(loc3 != (EIF_POINTER) NULL)) {
		tr1 = RTLNS(eif_new_type(837, 0x00).id, 837, _OBJSIZ_2_1_0_0_0_0_0_0_);
		F838_6465(RTCW(tr1), loc3);
		loc1 = (EIF_REFERENCE) tr1;
		tr1 = RTLNS(eif_new_type(827, 0x00).id, 827, _OBJSIZ_4_6_2_4_1_1_2_1_);
		F827_5982(RTCW(tr1), loc1);
		loc2 = (EIF_REFERENCE) tr1;
		tb1 = '\01';
		tb2 = F827_6012(RTCW(loc2));
		if (!(EIF_BOOLEAN) !tb2) {
			tb2 = F827_6021(RTCW(loc2));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			F1173_10724(Current);
		}
		g_free((gpointer) loc3);
	}
	RTLE;
}

/* {EV_FILE_DIALOG_IMP}.interface */
static EIF_REFERENCE F1174_10741_body (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_REFERENCE) 0;
}

EIF_REFERENCE F1174_10741 (EIF_REFERENCE Current)
{
	EIF_REFERENCE r;
	r = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if (!r) {
		if (RTAT(eif_final_id(Y7713,Y7713_gen_type,Dftype(Current),1103))) {
			GTCX
			RTLD;
			RTLI(1);
			RTLR(0,Current);
			RTLIU(1);
			r = (F1174_10741_body (Current));
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = r;
			RTAR(Current, r);
			RTLE;
		}
	}
	return r;
}


void EIF_Minit535 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
